{% extends view.base_template %}
<form method="post">
{% block content %}
    {% include "dashboard/crud/breadcrumb.html" %}
    {% include "forms/container/submit.html" with form=form %}
</form>
{% endblock %}