{% extends "base.html" %}
{% load static %}
{% block content %}
    {% include "messages.html" %}
    <div class="bg-gray-50 flex flex-col py-12 sm:px-6 lg:px-8">
        <div class="sm:mx-auto sm:w-full sm:max-w-md">
            <img class="mx-auto h-12 w-auto" src="https://tailwindui.com/img/logos/workflow-mark-pc-600.svg"
                 alt="Workflow">
            <h2 class="mt-6 text-center text-3xl font-extrabold text-gray-900">
                Forgot Password
            </h2>
        </div>

        <div class="mt-8 sm:mx-auto sm:w-full sm:max-w-md">
            <div class="bg-white py-8 px-4 shadow sm:rounded-lg sm:px-10">
                <form class="space-y-6" method="POST" action="{% url 'password_reset' %}">
                    {% csrf_token %}
                    <div>
                        <label for="email" class="block text-sm font-medium text-gray-700">
                            E-Mail
                        </label>
                        <div class="mt-1">
                            <input autofocus tabindex="1" id="email" name="email" type="email" autocomplete="email" required
                                   class="appearance-none block w-full px-3 py-2 border border-gray-300 rounded-md shadow-sm placeholder-gray-400 focus:outline-none focus:ring-pc-500 focus:border-pc-500 sm:text-sm">
                        </div>
                    </div>

                    <div>
                        <button tabindex="3" type="submit"
                                class="w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-pc-600 hover:bg-pc-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-pc-500">
                            Submit Request
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
{% endblock %}